<?php
/**
 * SEO Articles by AllinWriter - PRO Add-on.
 *
 * @package   WPSEOARTICLES
 * @copyright Copyright (C) 2022-2024, ALLINWRITER S.R.L. - office@allinwriter.com
 * @license   http://www.gnu.org/licenses/gpl-3.0.html GNU General Public License, version 3 or higher
 *
 * @wordpress-plugin
 * Plugin Name: SEO Articles by AllinWriter - PRO Add-on
 * Version:     1.0
 * Plugin URI:  https://allinwriter.com
 * Description: Generating SEO articles with high scoring using an AI SEO tool enhances content ranking, aiming for top Google positions.
 * Author:      AllinWriter
 * Author URI:  https://allinwriter.com
 * Text Domain: seo-articles-by-allinwriter-pro
 * License:     GPL v3
 * Requires at least: 6.5
 * Requires PHP: 7.2.5
 *
 * WC requires at least: 7.1
 * WC tested up to: 9.3
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

defined( 'ABSPATH' ) || exit;

add_filter( 'allinwriter_custom_fields', 'add_custom_allinwriter_fields', 99 );

function add_custom_allinwriter_fields( $default ) {
    return '
        <label for="allinwriter-type">Article Type*:</label>
        <select id="allinwriter-type" name="type" required>
            <option value="generateArticle">SEO Article Light</option>
            <option value="generateArticlePRO">SEO Article PRO</option>
        </select>

        <div class="allinwriter-write-method">
            <label for="allinwriter-method-type">Write option*:</label>
            <select id="allinwriter-method-type" name="type" required>
                <option value="rewrite" selected>Optimize current article</option>
                <option value="write">New article</option>
            </select>
        </div>
    ';
}

add_filter( 'allinwriter_after_credits_page', 'add_credits_page', 99 );

function add_credits_page( $default ) {
    return '
        <li>
        <b>' . esc_html__( 'SEO Article Pro', 'seo-articles-by-allinwriter-pro' ) . '</b>
        <ul>
            <li><p>' . esc_html__( 'This generation costs 50 credits.', 'seo-articles-by-allinwriter-pro' ) . '</p></li>
            <li><p>' . esc_html__( 'Each SEO Article PRO is approximately 3000 words, up-to-date, and provides relevant content with automated keyword research to optimize for secondary keywords, achieving a content SEO score of around 90%.', 'seo-articles-by-allinwriter-pro' ) . '</p></li>
            <li><p>' . esc_html__( 'SEO Article Pro increases your chance of ranking in the top on Google by 500+%.', 'seo-articles-by-allinwriter-pro' ) . '</p></li>
        </ul>
        </li>
        <li>
        <b>' . esc_html__( 'SEO Optimizer Pro', 'seo-articles-by-allinwriter-pro' ) . '</b>
        <ul>
            <li><p>' . esc_html__( 'Each generation costs 20 credits for any content up to 1000 words.', 'seo-articles-by-allinwriter-pro' ) . '</p></li>
            <li><p>' . esc_html__( 'If the content creation involves more than 1000 words, it is charged 20 credits for every additional maximum 1000 words.', 'seo-articles-by-allinwriter-pro' ) . '</p></li>
        </ul>
        </li>
    ';
}

add_filter( 'allinwriter_before_faq_page', 'add_faq_page', 99 );

function add_faq_page( $default ) {
    return '
    <li>
    <b>' . esc_html__( 'What is the difference between SEO Article Light and PRO?', 'seo-articles-by-allinwriter-pro' ) . '</b>
    <ul>
        <li>
            <p>' . esc_html__( 'SEO Article Light is shorter and uses fewer credits, but it is less optimized than the PRO version, which offers comprehensive content and a higher SEO score.', 'seo-articles-by-allinwriter-pro' ) . '</p>
        </li>
    </ul>
    </li>
    <li>
    <b>' . esc_html__( 'How can I optimize the SEO of an already written or published article?', 'seo-articles-by-allinwriter-pro' ) . '</b>
    <ul>
        <li>
            <p>' . esc_html__( 'Use the SEO Article PRO feature on an article in edit mode. Select the “optimize current article” option and input your target keyword. The tool will rewrite the article to be SEO-optimized, incorporating the target keywords while preserving the original information.', 'seo-articles-by-allinwriter-pro' ) . '</p>
        </li>
    </ul>
    </li>
    ';
}

// Hook into the activation process
register_activation_hook(__FILE__, 'check_free_plugin_activation');

function check_free_plugin_activation() {
    // Plugin path relative to the plugins folder
    $free_plugin_path = 'seo-articles-by-allinwriter/seo-articles-by-allinwriter.php'; 

    // Check if the free plugin is active
    include_once( ABSPATH . 'wp-admin/includes/plugin.php' );

    if (!is_plugin_active($free_plugin_path)) {
        // Deactivate the PRO plugin by referencing its own file
        deactivate_plugins(plugin_basename(__FILE__));
        
        // Show an error message
        wp_die(
            __('The PRO plugin requires the SEO Articles by AllinWriter - AI SEO Tool plugin to be installed and activated. <br> Please make sure the Free plugin is active before activating the PRO plugin.', 'seo-articles-by-allinwriter-pro'),
            __('Plugin dependency check', 'seo-articles-by-allinwriter-pro'),
            array('back_link' => true)
        );
    }
}